@@ -3,7 +3,7 @@
    Support for executable statements. */
 
 /*
- * Copyright (c) 2004 by Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (c) 2004-2006 by Internet Systems Consortium, Inc. ("ISC")
  * Copyright (c) 1998-2003 by Internet Software Consortium
  *
  * Permission to use, copy, modify, and distribute this software for any
@@ -34,7 +34,7 @@
 
 #ifndef lint
 static char copyright[] =
-"$Id: execute.c,v 1.44.2.10 2004/06/10 17:59:17 dhankins Exp $ Copyright (c) 2004 Internet Systems Consortium.  All rights reserved.\n";
+"$Id: execute.c,v 1.44.2.15 2006/02/22 22:43:27 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium.  All rights reserved.\n";
 #endif /* not lint */
 
 #include "dhcpd.h"
@@ -370,7 +370,9 @@ int execute_statements (result, packet, lease, client_state,
 					goto blb;
 				    }
 				}
-			}
+			} else
+				binding = NULL;
+
 			if (ns && binding) {
 				status = (evaluate_expression
 					  (&binding -> value, packet, lease,
@@ -420,19 +422,19 @@ int execute_statements (result, packet, lease, client_state,
 				switch (r -> data.log.priority) {
 				case log_priority_fatal:
 					log_fatal ("%.*s", (int)ds.len,
-						   ds.buffer -> data);
+						ds.data);
 					break;
 				case log_priority_error:
 					log_error ("%.*s", (int)ds.len,
-						   ds.buffer -> data);
+						ds.data);
 					break;
 				case log_priority_debug:
 					log_debug ("%.*s", (int)ds.len,
-						   ds.buffer -> data);
+						ds.data);
 					break;
 				case log_priority_info:
 					log_info ("%.*s", (int)ds.len,
-						  ds.buffer -> data);
+						ds.data);
 					break;
 				}
 				data_string_forget (&ds, MDL);
@@ -850,7 +852,7 @@ void write_statements (file, statements, indent)
 		      case log_statement:
 			indent_spaces (file, indent);
 			fprintf (file, "log ");
-			col = token_print_indent (file, col, indent + 4,
+			col = token_print_indent (file, indent + 4, indent + 4,
 						  "", "", "(");
 			switch (r -> data.log.priority) {
 			case log_priority_fatal:
